@@ -612,3 +612,13 @@ class SupplyDemandMetric(Enum):
     NetExport = "netExport"  #:
     StockChange = "stockChange"  #:
     BalancingFactor = "balancingFactor"  #:
+
+class FixturesStatuses(Enum):
+    """"""
+
+    OnSubs = "on subs"  #:
+    InProgress = "in progress"  #:
+    FullyFixed = "fully fixed"  #:
+    Finished = "finished"  #:
+    Failed = "failed"  #:
+    Cancelled = "cancelled"  #:
\ No newline at end of file
