@@ -2,6 +2,8 @@ from datetime import date
 from enum import Enum
 from typing import List, Optional
 
+from pandas import DataFrame
+
 from kpler.sdk import Platform
 from kpler.sdk.client import KplerClient
 from kpler.sdk.configuration import Configuration
@@ -21,12 +23,34 @@ class FleetUtilizationVessels(KplerClient):
     """
 
     RESOURCE_NAME = "fleet-utilization/vessels"
+    COLUMNS_RESOURCE_NAME = "fleet-utilization"
 
     AVAILABLE_PLATFORMS = [Platform.Dry, Platform.Liquids, Platform.LNG, Platform.LPG]
 
     def __init__(self, configuration: Configuration, column_ids: bool = True, log_level=None):
         super().__init__(configuration, self.AVAILABLE_PLATFORMS, column_ids, log_level)
 
+    def get_columns(self) -> DataFrame:
+        """
+        This endpoint returns a recent and updated list of all columns available for the endpoint fleet-utilization.
+
+        Examples:
+            >>> from kpler.sdk.resources.fleet_utilization_vessels import FleetUtilizationVessels
+            ... fleet_utilization_vessels_client=FleetUtilizationVessels(config)
+            ... fleet_utilization_vessels_client.get_columns()
+
+            .. csv-table::
+                :header: "id","name","description","deprecated","type"
+
+                "date","Date (timestamp)","","False","date yyyy-MM-dd"
+                "vessel_imo","IMO","IMO of the vessel","False","long"
+                "vessel","Name","Name of the vessel","False","string"
+                "vessel_dwt_tons","Dead Weight Tonnage","Dead Weight Tonnage","False","long"
+                "vessel_type","Vessel Type","Type of the vessel","False","string"
+                "...","...","...","...","..."
+        """
+        return self._get_columns_for_resource(self.COLUMNS_RESOURCE_NAME)
+
     def get(
         self,
         start_date: Optional[date] = None,
