@@ -12,7 +12,7 @@ from kpler.sdk.helpers import process_bool_parameter, process_date_parameter, pr
 class PortCalls(KplerClient):
     """
     The ``PortCalls`` query returns the cargo-by-cargo details for loadings/discharges taking place in a point of
-    interest (installation/zone). Historical data goes back to 2013.
+    interest (installation/zone).
     """
 
     RESOURCE_NAME = "port-calls"
